@@ -1,7 +1,7 @@
 package Bencher::Scenario::AppLcpan::Completion;
 
 our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +49,7 @@ Bencher::Scenario::AppLcpan::Completion - Benchmark completion response time, to
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::AppLcpan::Completion (from Perl distribution Bencher-Scenarios-AppLcpan), released on 2016-01-06.
+This document describes version 0.03 of Bencher::Scenario::AppLcpan::Completion (from Perl distribution Bencher-Scenarios-AppLcpan), released on 2016-01-06.
 
 =head1 SYNOPSIS
 
@@ -102,10 +102,10 @@ Benchmark with default option:
  +-----+------------------------+------+--------+---------+---------+
  | seq | name                   | rate | time   | errors  | samples |
  +-----+------------------------+------+--------+---------+---------+
- | 3   | optval_author          | 9.63 | 104ms  | 9.8e-05 | 20      |
- | 2   | subcmd_author          | 16.2 | 61.7ms | 0.00017 | 20      |
- | 1   | optname_common_version | 16   | 61ms   | 0.00029 | 20      |
- | 0   | optname_common_help    | 16.5 | 60.8ms | 0.00013 | 20      |
+ | 3   | optval_author          | 9.27 | 108ms  | 0.00034 | 21      |
+ | 1   | optname_common_version | 15   | 65ms   | 0.00041 | 21      |
+ | 2   | subcmd_author          | 15.5 | 64.5ms | 0.00014 | 20      |
+ | 0   | optname_common_help    | 15.8 | 63.1ms | 0.00015 | 20      |
  +-----+------------------------+------+--------+---------+---------+
 
 =head1 DESCRIPTION
