@@ -1,7 +1,7 @@
-package Bencher::Scenarios::App::Lcpan;
+package Bencher::Scenarios::AppLcpan;
 
 our $DATE = '2016-01-06'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 1;
 # ABSTRACT: A collection of scenarios to benchmark App::lcpan
@@ -14,11 +14,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenarios::App::Lcpan - A collection of scenarios to benchmark App::lcpan
+Bencher::Scenarios::AppLcpan - A collection of scenarios to benchmark App::lcpan
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenarios::App::Lcpan (from Perl distribution Bencher-Scenarios-AppLcpan), released on 2016-01-06.
+This document describes version 0.03 of Bencher::Scenarios::AppLcpan (from Perl distribution Bencher-Scenarios-AppLcpan), released on 2016-01-06.
 
 =head1 SEE ALSO
 
